==> jc-1.4.0.tar.gz: javax/security/auth/login/AppConfigurationEntry__24LoginModuleControlFlag.h <==
// public class javax.security.auth.login.AppConfigurationEntry$LoginModuleControlFlag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d7af8364e1309d5e javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag_H_
#define _JC_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object;

typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct {
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*OPTIONAL;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*REQUIRED;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*REQUISITE;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*SUFFICIENT;
	struct _jc_java_lang_Class$object	*class__24javax__24security__24auth__24login__24AppConfigurationEntry__24LoginModuleControlFlag;
};
extern _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *);
};

// Vtable
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods	javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag;
};

// Vtype
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs {
    _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs	javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs	javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag;
};

// Object instance structure
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object {
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype	*vtype;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$class_object;

#endif	/* _JC_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag_H_ */

==> jc-1.4.6.tar.gz: javax/security/auth/login/AppConfigurationEntry__24LoginModuleControlFlag.h <==
// public class javax.security.auth.login.AppConfigurationEntry$LoginModuleControlFlag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d7af8364e1309d5e javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag_H_
#define _JC_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object;

// Typedefs
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs;
typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object;

typedef struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable;
typedef const struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype;

// Class fields structure
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct {
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*OPTIONAL;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*REQUIRED;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*REQUISITE;
	struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object	*SUFFICIENT;
	struct _jc_java_lang_Class$object	*class__24javax__24security__24auth__24login__24AppConfigurationEntry__24LoginModuleControlFlag;
};
extern _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$fields_struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$class_fields;

// Constructors
extern void _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vmethods	javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag;
};

// Vtype
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype {
	_jc_type			type;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs {
    _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_refs	javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$sub_nonrefs	javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag;
};

// Object instance structure
struct _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$object {
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype	*vtype;
	_jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$vtype _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag$class_object;

#endif	/* _JC_javax_security_auth_login_AppConfigurationEntry__24LoginModuleControlFlag_H_ */
